@@ -147,6 +147,7 @@ namespace
 		myPlaylistEditor->hasToBeResized = 1;
 		myLyrics->hasToBeResized = 1;
 		mySelectedItemsAdder->hasToBeResized = 1;
+		mySongInfo->hasToBeResized = 1;
 		
 #		ifdef HAVE_CURL_CURL_H
 		myLastfm->hasToBeResized = 1;
@@ -322,7 +323,8 @@ int main(int argc, char *argv[])
 	signal(SIGWINCH, sighandler);
 #	endif // !WIN32
 	
-	MEVENT mouse_event;
+	MEVENT mouse_event, old_mouse_event;
+	old_mouse_event.bstate = 0;
 	mouseinterval(0);
 	if (Config.mouse_support)
 		mousemask(ALL_MOUSE_EVENTS, 0);
@@ -412,6 +414,9 @@ int main(int argc, char *argv[])
 #				ifdef ENABLE_VISUALIZER
 				*wHeader << "  " << fmtBold << char(Key.Visualizer[0]) << fmtBoldEnd << ":Music visualizer";
 #				endif // ENABLE_VISUALIZER
+#				ifdef ENABLE_OUTPUTS
+				*wHeader << "  " << fmtBold << char(Key.Outputs[0]) << fmtBoldEnd << ":Outputs";
+#				endif // ENABLE_OUTPUTS
 #				ifdef ENABLE_CLOCK
 				*wHeader << "  " << fmtBold << char(Key.Clock[0]) << fmtBoldEnd << ":Clock";
 #				endif // ENABLE_CLOCK
@@ -522,6 +527,15 @@ int main(int argc, char *argv[])
 		else if (Config.mouse_support && input == KEY_MOUSE)
 		{
 			getmouse(&mouse_event);
+			// workaround shitty ncurses behavior introduced in >=5.8, when we mysteriously get
+			// a few times after ncmpcpp startup 2^27 code instead of BUTTON{1,3}_RELEASED. since that
+			// 2^27 thing shows constantly instead of BUTTON2_PRESSED, it was redefined to be recognized
+			// as BUTTON2_PRESSED. but clearly we don't want to trigger behavior bound to BUTTON2
+			// after BUTTON{1,3} was pressed. so, here is the workaround: if last event was BUTTON{1,3}_PRESSED,
+			// we MUST get BUTTON{1,3}_RELEASED afterwards. if we get BUTTON2_PRESSED, erroneus behavior
+			// is about to occur and we need to prevent that.
+			if (old_mouse_event.bstate & (BUTTON1_PRESSED | BUTTON3_PRESSED) && mouse_event.bstate & BUTTON2_PRESSED)
+				continue;
 			if (mouse_event.bstate & BUTTON1_PRESSED
 			&&  mouse_event.y == LINES-(Config.statusbar_visibility ? 2 : 1)
 			   ) // progressbar
@@ -552,6 +566,7 @@ int main(int argc, char *argv[])
 			}
 			else if (mouse_event.bstate & (BUTTON1_PRESSED | BUTTON2_PRESSED | BUTTON3_PRESSED | BUTTON4_PRESSED))
 				myScreen->MouseButtonPressed(mouse_event);
+			old_mouse_event = mouse_event;
 		}
 		else if (Keypressed(input, Key.ToggleInterface))
 		{
@@ -1256,6 +1271,7 @@ int main(int argc, char *argv[])
 			LockStatusbar();
 			Statusbar() << (myScreen == myPlaylistEditor ? "Add to playlist: " : "Add: ");
 			std::string path = wFooter->GetString();
+			locale_to_utf(path);
 			UnlockStatusbar();
 			if (!path.empty())
 			{
@@ -1270,7 +1286,11 @@ int main(int argc, char *argv[])
 				{
 					static const char lastfm_url[] = "lastfm://";
 					if (path.compare(0, static_strlen(lastfm_url), lastfm_url) == 0
-					||  path.find(".pls", path.length()-4) != std::string::npos)
+					||  path.find(".asx", path.length()-4) != std::string::npos
+					||  path.find(".cue", path.length()-4) != std::string::npos
+					||  path.find(".m3u", path.length()-4) != std::string::npos
+					||  path.find(".pls", path.length()-4) != std::string::npos
+					||  path.find(".xspf", path.length()-5) != std::string::npos)
 						Mpd.LoadPlaylist(path);
 					else
 						Mpd.Add(path);
@@ -2218,6 +2238,24 @@ int main(int argc, char *argv[])
 					(*screen)->SwitchTo();
 			}
 		}
+		else if (!Config.screen_switcher_previous && Keypressed(input, Key.BackwardScreenSwitcher))
+		{
+			if (Config.screen_switcher_previous)
+			{
+				if (myScreen->isTabbable())
+					myPrevScreen->SwitchTo();
+				else
+					myOldScreen->SwitchTo();
+			}
+			else if (!Config.screens_seq.empty())
+			{
+				std::list<BasicScreen *>::const_iterator screen = std::find(Config.screens_seq.begin(), Config.screens_seq.end(), myScreen);
+				if (screen == Config.screens_seq.begin())
+					(*Config.screens_seq.rbegin())->SwitchTo();
+				else
+					(*--screen)->SwitchTo();
+			}
+		}
 		else if (Keypressed(input, Key.Playlist))
 		{
 			myPlaylist->SwitchTo();
