@@ -123,6 +123,19 @@ namespace
 				return 0;
 		}
 	}
+	
+	std::string RemoveDollarFormatting(const std::string &s)
+	{
+		std::string result;
+		for (size_t i = 0; i < s.size(); ++i)
+		{
+			if (s[i] != '$')
+				result += s[i];
+			else
+				++i;
+		}
+		return result;
+	}
 }
 
 void CreateConfigDir()
@@ -172,6 +185,7 @@ void NcmpcppKeys::SetDefaults()
 	PrevColumn[0] = KEY_LEFT;
 	NextColumn[0] = KEY_RIGHT;
 	ScreenSwitcher[0] = 9;
+	BackwardScreenSwitcher[0] = 353;
 	Help[0] = '1';
 	Playlist[0] = '2';
 	Browser[0] = '3';
@@ -259,6 +273,7 @@ void NcmpcppKeys::SetDefaults()
 	PrevColumn[1] = NullKey;
 	NextColumn[1] = NullKey;
 	ScreenSwitcher[1] = NullKey;
+	BackwardScreenSwitcher[1] = NullKey;
 	Help[1] = 265;
 	Playlist[1] = 266;
 	Browser[1] = 267;
@@ -335,6 +350,7 @@ void NcmpcppConfig::SetDefaults()
 	empty_tag = "<empty>";
 	song_list_columns_format = "(7f)[green]{l} (25)[cyan]{a} (40)[]{t|f} (30)[red]{b}";
 	song_list_format = "{{%a - }{%t}|{$8%f$9}$R{$3(%l)$9}}";
+	song_list_format_dollar_free = RemoveDollarFormatting(song_list_format);
 	song_status_format = "{{{%a{ \"%b\"{ (%y)}} - }{%t}}|{%f}}";
 	song_status_format_no_colors = song_status_format;
 	song_window_title_format = "{{%a - }{%t}|{%f}}";
@@ -488,6 +504,8 @@ void NcmpcppKeys::Read()
 				GetKeys(key, NextColumn);
 			else if (key.find("key_screen_switcher ") != std::string::npos)
 				GetKeys(key, ScreenSwitcher);
+			else if (key.find("key_backward_screen_switcher ") != std::string::npos)
+				GetKeys(key, BackwardScreenSwitcher);
 			else if (key.find("key_help ") != std::string::npos)
 				GetKeys(key, Help);
 			else if (key.find("key_playlist ") != std::string::npos)
@@ -698,6 +716,7 @@ void NcmpcppConfig::Read()
 					song_list_format = '{';
 					song_list_format += v;
 					song_list_format += '}';
+					song_list_format_dollar_free = RemoveDollarFormatting(song_list_format);
 				}
 			}
 			else if (cl.find("song_columns_list_format") != std::string::npos)
