@@ -76,6 +76,7 @@ struct NcmpcppKeys
 	int PrevColumn[2];
 	int NextColumn[2];
 	int ScreenSwitcher[2];
+	int BackwardScreenSwitcher[2];
 	int Help[2];
 	int Playlist[2];
 	int Browser[2];
@@ -158,6 +159,7 @@ struct NcmpcppConfig
 	std::string empty_tag;
 	std::string song_list_columns_format;
 	std::string song_list_format;
+	std::string song_list_format_dollar_free;
 	std::string song_status_format;
 	std::string song_status_format_no_colors;
 	std::string song_window_title_format;
